@@ -331,10 +331,85 @@ class ShellCommand(Command):
         return vars(options)
 
 class PigCommand(Command):
+    usage = ("pigcmd run [options] [key1=value1] [key2=value2] ...")
+               
+
+    optparser = GentleOptionParser(usage=usage)
+    optparser.add_option("-s", "--script", dest="latin_statements",
+                         help="latin statements that has to be executed")
+
+    optparser.add_option("-f", "--script_location", dest="script_location", 
+                         help="Path where bash script to run is stored. Can be S3 URI or local file path")
+
     @classmethod
     def parse(cls, args):
-        raise ParseError("pigcmd not implemented yet", "")
-    pass
+        """
+        Parse command line arguments to construct a dictionary of command
+        parameters that can be used to create a command
+
+        Args:
+            `args` - sequence of arguments
+
+        Returns:
+            Dictionary that can be used in create method
+
+        Raises:
+            ParseError: when the arguments are not correct
+        """
+
+        try:
+            (options, args) = cls.optparser.parse_args(args)
+            if options.latin_statements is None and options.script_location is None:
+                raise ParseError("One of script or it's location"
+                                 " must be specified", 
+                                 cls.optparser.format_help())
+        except OptionParsingError as e:
+            raise ParseError(e.msg, cls.optparser.format_help())
+        except OptionParsingExit as e:
+            return None
+
+        if options.script_location is not None:
+            if options.latin_statements is not None:
+                raise ParseError(
+                    "Both script and script_location cannot be specified", 
+                    cls.optparser.format_help())
+
+            if ((options.script_location.find("s3://") != 0) and
+                (options.script_location.find("s3n://") != 0)):
+
+                # script location is local file
+                
+                try:
+                    s = open(options.script_location).read()
+                except:
+                    raise ParseError("Unable to open script location: %s" % 
+                                     options.script_location,
+                                     cls.optparser.format_help())
+                options.script_location = None
+                options.latin_statements = s
+
+            if ((args is not None) and (len(args) > 0)):
+                if options.latin_statements is not None:
+                    raise ParseError(
+                        "This sucks - but extra arguments can only be "
+                        "supplied with a script_location in S3 right now",
+                        cls.optparser.format_help())
+
+                p = {}
+                for a in args:
+                  kv = a.split('=')
+                  if len(kv)!=2:
+                    raise ParseError("Arguments to pig script must be of this format k1=v1 k2=v2 k3=v3...")
+                  p[kv[0]] = kv[1]
+                setattr(options, 'parameters',p)
+
+        else:
+            if ((args is not None) and (len(args) > 0)):
+                raise ParseError(
+                    "Extra arguments can only be supplied with a script_location",
+                    cls.optparser.format_help())                
+        
+        return vars(options)
 
 class DbImportCommand(Command):
     @classmethod
